# coding: utf-8

"""
    Transactional Single Send

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.transactional.configuration import Configuration


class EmailSendStatusView(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"event_id": "EventIdView", "completed_at": "datetime", "status_id": "str", "send_result": "str", "requested_at": "datetime", "started_at": "datetime", "status": "str"}

    attribute_map = {
        "event_id": "eventId",
        "completed_at": "completedAt",
        "status_id": "statusId",
        "send_result": "sendResult",
        "requested_at": "requestedAt",
        "started_at": "startedAt",
        "status": "status",
    }

    def __init__(self, event_id=None, completed_at=None, status_id=None, send_result=None, requested_at=None, started_at=None, status=None, local_vars_configuration=None):  # noqa: E501
        """EmailSendStatusView - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._event_id = None
        self._completed_at = None
        self._status_id = None
        self._send_result = None
        self._requested_at = None
        self._started_at = None
        self._status = None
        self.discriminator = None

        if event_id is not None:
            self.event_id = event_id
        if completed_at is not None:
            self.completed_at = completed_at
        self.status_id = status_id
        if send_result is not None:
            self.send_result = send_result
        if requested_at is not None:
            self.requested_at = requested_at
        if started_at is not None:
            self.started_at = started_at
        self.status = status

    @property
    def event_id(self):
        """Gets the event_id of this EmailSendStatusView.  # noqa: E501


        :return: The event_id of this EmailSendStatusView.  # noqa: E501
        :rtype: EventIdView
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this EmailSendStatusView.


        :param event_id: The event_id of this EmailSendStatusView.  # noqa: E501
        :type event_id: EventIdView
        """

        self._event_id = event_id

    @property
    def completed_at(self):
        """Gets the completed_at of this EmailSendStatusView.  # noqa: E501

        Time when the send was completed.  # noqa: E501

        :return: The completed_at of this EmailSendStatusView.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this EmailSendStatusView.

        Time when the send was completed.  # noqa: E501

        :param completed_at: The completed_at of this EmailSendStatusView.  # noqa: E501
        :type completed_at: datetime
        """

        self._completed_at = completed_at

    @property
    def status_id(self):
        """Gets the status_id of this EmailSendStatusView.  # noqa: E501

        Identifier used to query the status of the send.  # noqa: E501

        :return: The status_id of this EmailSendStatusView.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this EmailSendStatusView.

        Identifier used to query the status of the send.  # noqa: E501

        :param status_id: The status_id of this EmailSendStatusView.  # noqa: E501
        :type status_id: str
        """
        if self.local_vars_configuration.client_side_validation and status_id is None:  # noqa: E501
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def send_result(self):
        """Gets the send_result of this EmailSendStatusView.  # noqa: E501

        Result of the send.  # noqa: E501

        :return: The send_result of this EmailSendStatusView.  # noqa: E501
        :rtype: str
        """
        return self._send_result

    @send_result.setter
    def send_result(self, send_result):
        """Sets the send_result of this EmailSendStatusView.

        Result of the send.  # noqa: E501

        :param send_result: The send_result of this EmailSendStatusView.  # noqa: E501
        :type send_result: str
        """
        allowed_values = [
            "SENT",
            "IDEMPOTENT_IGNORE",
            "QUEUED",
            "IDEMPOTENT_FAIL",
            "THROTTLED",
            "EMAIL_DISABLED",
            "PORTAL_SUSPENDED",
            "INVALID_TO_ADDRESS",
            "BLOCKED_DOMAIN",
            "PREVIOUSLY_BOUNCED",
            "EMAIL_UNCONFIRMED",
            "PREVIOUS_SPAM",
            "PREVIOUSLY_UNSUBSCRIBED_MESSAGE",
            "PREVIOUSLY_UNSUBSCRIBED_PORTAL",
            "INVALID_FROM_ADDRESS",
            "CAMPAIGN_CANCELLED",
            "VALIDATION_FAILED",
            "MTA_IGNORE",
            "BLOCKED_ADDRESS",
            "PORTAL_OVER_LIMIT",
            "PORTAL_EXPIRED",
            "PORTAL_MISSING_MARKETING_SCOPE",
            "MISSING_TEMPLATE_PROPERTIES",
            "MISSING_REQUIRED_PARAMETER",
            "PORTAL_AUTHENTICATION_FAILURE",
            "MISSING_CONTENT",
            "CORRUPT_INPUT",
            "TEMPLATE_RENDER_EXCEPTION",
            "GRAYMAIL_SUPPRESSED",
            "UNCONFIGURED_SENDING_DOMAIN",
            "UNDELIVERABLE",
            "CANCELLED_ABUSE",
            "QUARANTINED_ADDRESS",
            "ADDRESS_ONLY_ACCEPTED_ON_PROD",
            "PORTAL_NOT_AUTHORIZED_FOR_APPLICATION",
            "ADDRESS_LIST_BOMBED",
            "ADDRESS_OPTED_OUT",
            "RECIPIENT_FATIGUE_SUPPRESSED",
            "TOO_MANY_RECIPIENTS",
            "PREVIOUSLY_UNSUBSCRIBED_BRAND",
            "NON_MARKETABLE_CONTACT",
            "PREVIOUSLY_UNSUBSCRIBED_BUSINESS_UNIT",
            "GDPR_DOI_ENABLED",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and send_result not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `send_result` ({0}), must be one of {1}".format(send_result, allowed_values))  # noqa: E501

        self._send_result = send_result

    @property
    def requested_at(self):
        """Gets the requested_at of this EmailSendStatusView.  # noqa: E501

        Time when the send was requested.  # noqa: E501

        :return: The requested_at of this EmailSendStatusView.  # noqa: E501
        :rtype: datetime
        """
        return self._requested_at

    @requested_at.setter
    def requested_at(self, requested_at):
        """Sets the requested_at of this EmailSendStatusView.

        Time when the send was requested.  # noqa: E501

        :param requested_at: The requested_at of this EmailSendStatusView.  # noqa: E501
        :type requested_at: datetime
        """

        self._requested_at = requested_at

    @property
    def started_at(self):
        """Gets the started_at of this EmailSendStatusView.  # noqa: E501

        Time when the send began processing.  # noqa: E501

        :return: The started_at of this EmailSendStatusView.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this EmailSendStatusView.

        Time when the send began processing.  # noqa: E501

        :param started_at: The started_at of this EmailSendStatusView.  # noqa: E501
        :type started_at: datetime
        """

        self._started_at = started_at

    @property
    def status(self):
        """Gets the status of this EmailSendStatusView.  # noqa: E501

        Status of the send request.  # noqa: E501

        :return: The status of this EmailSendStatusView.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this EmailSendStatusView.

        Status of the send request.  # noqa: E501

        :param status: The status of this EmailSendStatusView.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "PROCESSING", "CANCELED", "COMPLETE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values))  # noqa: E501

        self._status = status

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailSendStatusView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailSendStatusView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class ListCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "object_type_id": "str",
        "processing_type": "str",
        "custom_properties": "dict[str, str]",
        "list_folder_id": "int",
        "name": "str",
        "filter_branch": "PublicPropertyAssociationFilterBranchFilterBranchesInner",
    }

    attribute_map = {
        "object_type_id": "objectTypeId",
        "processing_type": "processingType",
        "custom_properties": "customProperties",
        "list_folder_id": "listFolderId",
        "name": "name",
        "filter_branch": "filterBranch",
    }

    def __init__(self, object_type_id=None, processing_type=None, custom_properties=None, list_folder_id=None, name=None, filter_branch=None, local_vars_configuration=None):  # noqa: E501
        """ListCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._object_type_id = None
        self._processing_type = None
        self._custom_properties = None
        self._list_folder_id = None
        self._name = None
        self._filter_branch = None
        self.discriminator = None

        self.object_type_id = object_type_id
        self.processing_type = processing_type
        if custom_properties is not None:
            self.custom_properties = custom_properties
        if list_folder_id is not None:
            self.list_folder_id = list_folder_id
        self.name = name
        if filter_branch is not None:
            self.filter_branch = filter_branch

    @property
    def object_type_id(self):
        """Gets the object_type_id of this ListCreateRequest.  # noqa: E501

        The object type ID of the type of objects that the list will store.  # noqa: E501

        :return: The object_type_id of this ListCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._object_type_id

    @object_type_id.setter
    def object_type_id(self, object_type_id):
        """Sets the object_type_id of this ListCreateRequest.

        The object type ID of the type of objects that the list will store.  # noqa: E501

        :param object_type_id: The object_type_id of this ListCreateRequest.  # noqa: E501
        :type object_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and object_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type_id`, must not be `None`")  # noqa: E501

        self._object_type_id = object_type_id

    @property
    def processing_type(self):
        """Gets the processing_type of this ListCreateRequest.  # noqa: E501

        The processing type of the list. One of: `SNAPSHOT`, `MANUAL`, or `DYNAMIC`.  # noqa: E501

        :return: The processing_type of this ListCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._processing_type

    @processing_type.setter
    def processing_type(self, processing_type):
        """Sets the processing_type of this ListCreateRequest.

        The processing type of the list. One of: `SNAPSHOT`, `MANUAL`, or `DYNAMIC`.  # noqa: E501

        :param processing_type: The processing_type of this ListCreateRequest.  # noqa: E501
        :type processing_type: str
        """
        if self.local_vars_configuration.client_side_validation and processing_type is None:  # noqa: E501
            raise ValueError("Invalid value for `processing_type`, must not be `None`")  # noqa: E501

        self._processing_type = processing_type

    @property
    def custom_properties(self):
        """Gets the custom_properties of this ListCreateRequest.  # noqa: E501

        The list of custom properties to tie to the list. Custom property name is the key, the value is the value.  # noqa: E501

        :return: The custom_properties of this ListCreateRequest.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._custom_properties

    @custom_properties.setter
    def custom_properties(self, custom_properties):
        """Sets the custom_properties of this ListCreateRequest.

        The list of custom properties to tie to the list. Custom property name is the key, the value is the value.  # noqa: E501

        :param custom_properties: The custom_properties of this ListCreateRequest.  # noqa: E501
        :type custom_properties: dict[str, str]
        """

        self._custom_properties = custom_properties

    @property
    def list_folder_id(self):
        """Gets the list_folder_id of this ListCreateRequest.  # noqa: E501

        The ID of the folder that the list should be created in. If left blank, then the list will be created in the root of the list folder structure.  # noqa: E501

        :return: The list_folder_id of this ListCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._list_folder_id

    @list_folder_id.setter
    def list_folder_id(self, list_folder_id):
        """Sets the list_folder_id of this ListCreateRequest.

        The ID of the folder that the list should be created in. If left blank, then the list will be created in the root of the list folder structure.  # noqa: E501

        :param list_folder_id: The list_folder_id of this ListCreateRequest.  # noqa: E501
        :type list_folder_id: int
        """

        self._list_folder_id = list_folder_id

    @property
    def name(self):
        """Gets the name of this ListCreateRequest.  # noqa: E501

        The name of the list, which must be globally unique across all public lists in the portal.  # noqa: E501

        :return: The name of this ListCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListCreateRequest.

        The name of the list, which must be globally unique across all public lists in the portal.  # noqa: E501

        :param name: The name of this ListCreateRequest.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def filter_branch(self):
        """Gets the filter_branch of this ListCreateRequest.  # noqa: E501


        :return: The filter_branch of this ListCreateRequest.  # noqa: E501
        :rtype: PublicPropertyAssociationFilterBranchFilterBranchesInner
        """
        return self._filter_branch

    @filter_branch.setter
    def filter_branch(self, filter_branch):
        """Sets the filter_branch of this ListCreateRequest.


        :param filter_branch: The filter_branch of this ListCreateRequest.  # noqa: E501
        :type filter_branch: PublicPropertyAssociationFilterBranchFilterBranchesInner
        """

        self._filter_branch = filter_branch

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListCreateRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    CRM Associations

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.associations.v4.api.basic_api import BasicApi
from hubspot.crm.associations.v4.api.batch_api import BatchApi
from hubspot.crm.associations.v4.api.report_api import ReportApi

# import ApiClient
from hubspot.crm.associations.v4.api_client import ApiClient
from hubspot.crm.associations.v4.configuration import Configuration
from hubspot.crm.associations.v4.exceptions import OpenApiException
from hubspot.crm.associations.v4.exceptions import ApiTypeError
from hubspot.crm.associations.v4.exceptions import ApiValueError
from hubspot.crm.associations.v4.exceptions import ApiKeyError
from hubspot.crm.associations.v4.exceptions import ApiAttributeError
from hubspot.crm.associations.v4.exceptions import ApiException

# import models into sdk package
from hubspot.crm.associations.v4.models.association_spec import AssociationSpec
from hubspot.crm.associations.v4.models.association_spec_with_label import AssociationSpecWithLabel
from hubspot.crm.associations.v4.models.batch_input_public_association_multi_archive import BatchInputPublicAssociationMultiArchive
from hubspot.crm.associations.v4.models.batch_input_public_association_multi_post import BatchInputPublicAssociationMultiPost
from hubspot.crm.associations.v4.models.batch_input_public_default_association_multi_post import BatchInputPublicDefaultAssociationMultiPost
from hubspot.crm.associations.v4.models.batch_input_public_fetch_associations_batch_request import BatchInputPublicFetchAssociationsBatchRequest
from hubspot.crm.associations.v4.models.batch_response_labels_between_object_pair import BatchResponseLabelsBetweenObjectPair
from hubspot.crm.associations.v4.models.batch_response_labels_between_object_pair_with_errors import BatchResponseLabelsBetweenObjectPairWithErrors
from hubspot.crm.associations.v4.models.batch_response_public_association_multi_with_label import BatchResponsePublicAssociationMultiWithLabel
from hubspot.crm.associations.v4.models.batch_response_public_association_multi_with_label_with_errors import BatchResponsePublicAssociationMultiWithLabelWithErrors
from hubspot.crm.associations.v4.models.batch_response_public_default_association import BatchResponsePublicDefaultAssociation
from hubspot.crm.associations.v4.models.collection_response_multi_associated_object_with_label_forward_paging import CollectionResponseMultiAssociatedObjectWithLabelForwardPaging
from hubspot.crm.associations.v4.models.date_time import DateTime
from hubspot.crm.associations.v4.models.error import Error
from hubspot.crm.associations.v4.models.error_detail import ErrorDetail
from hubspot.crm.associations.v4.models.forward_paging import ForwardPaging
from hubspot.crm.associations.v4.models.labels_between_object_pair import LabelsBetweenObjectPair
from hubspot.crm.associations.v4.models.multi_associated_object_with_label import MultiAssociatedObjectWithLabel
from hubspot.crm.associations.v4.models.next_page import NextPage
from hubspot.crm.associations.v4.models.paging import Paging
from hubspot.crm.associations.v4.models.previous_page import PreviousPage
from hubspot.crm.associations.v4.models.public_association_multi_archive import PublicAssociationMultiArchive
from hubspot.crm.associations.v4.models.public_association_multi_post import PublicAssociationMultiPost
from hubspot.crm.associations.v4.models.public_association_multi_with_label import PublicAssociationMultiWithLabel
from hubspot.crm.associations.v4.models.public_default_association import PublicDefaultAssociation
from hubspot.crm.associations.v4.models.public_default_association_multi_post import PublicDefaultAssociationMultiPost
from hubspot.crm.associations.v4.models.public_fetch_associations_batch_request import PublicFetchAssociationsBatchRequest
from hubspot.crm.associations.v4.models.public_object_id import PublicObjectId
from hubspot.crm.associations.v4.models.report_creation_response import ReportCreationResponse
from hubspot.crm.associations.v4.models.standard_error import StandardError



# coding: utf-8

# flake8: noqa
"""
    Events Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.events.models.collection_response_external_unified_event import CollectionResponseExternalUnifiedEvent
from hubspot.events.models.error import Error
from hubspot.events.models.error_detail import ErrorDetail
from hubspot.events.models.external_unified_event import ExternalUnifiedEvent
from hubspot.events.models.next_page import NextPage
from hubspot.events.models.paging import Paging
from hubspot.events.models.previous_page import PreviousPage
from hubspot.events.models.visible_external_event_type_names import VisibleExternalEventTypeNames



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicButtonStyleSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"background_color": "object", "font_style": "PublicFontStyle", "corner_radius": "int"}

    attribute_map = {"background_color": "backgroundColor", "font_style": "fontStyle", "corner_radius": "cornerRadius"}

    def __init__(self, background_color=None, font_style=None, corner_radius=None, local_vars_configuration=None):  # noqa: E501
        """PublicButtonStyleSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._background_color = None
        self._font_style = None
        self._corner_radius = None
        self.discriminator = None

        if background_color is not None:
            self.background_color = background_color
        if font_style is not None:
            self.font_style = font_style
        if corner_radius is not None:
            self.corner_radius = corner_radius

    @property
    def background_color(self):
        """Gets the background_color of this PublicButtonStyleSettings.  # noqa: E501


        :return: The background_color of this PublicButtonStyleSettings.  # noqa: E501
        :rtype: object
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """Sets the background_color of this PublicButtonStyleSettings.


        :param background_color: The background_color of this PublicButtonStyleSettings.  # noqa: E501
        :type background_color: object
        """

        self._background_color = background_color

    @property
    def font_style(self):
        """Gets the font_style of this PublicButtonStyleSettings.  # noqa: E501


        :return: The font_style of this PublicButtonStyleSettings.  # noqa: E501
        :rtype: PublicFontStyle
        """
        return self._font_style

    @font_style.setter
    def font_style(self, font_style):
        """Sets the font_style of this PublicButtonStyleSettings.


        :param font_style: The font_style of this PublicButtonStyleSettings.  # noqa: E501
        :type font_style: PublicFontStyle
        """

        self._font_style = font_style

    @property
    def corner_radius(self):
        """Gets the corner_radius of this PublicButtonStyleSettings.  # noqa: E501


        :return: The corner_radius of this PublicButtonStyleSettings.  # noqa: E501
        :rtype: int
        """
        return self._corner_radius

    @corner_radius.setter
    def corner_radius(self, corner_radius):
        """Sets the corner_radius of this PublicButtonStyleSettings.


        :param corner_radius: The corner_radius of this PublicButtonStyleSettings.  # noqa: E501
        :type corner_radius: int
        """

        self._corner_radius = corner_radius

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicButtonStyleSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicButtonStyleSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicListFolder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_at": "datetime",
        "parent_folder_id": "int",
        "child_nodes": "list[PublicListFolder]",
        "name": "str",
        "id": "int",
        "child_lists": "list[int]",
        "updated_contents_at": "datetime",
        "user_id": "int",
        "updated_at": "datetime",
    }

    attribute_map = {
        "created_at": "createdAt",
        "parent_folder_id": "parentFolderId",
        "child_nodes": "childNodes",
        "name": "name",
        "id": "id",
        "child_lists": "childLists",
        "updated_contents_at": "updatedContentsAt",
        "user_id": "userId",
        "updated_at": "updatedAt",
    }

    def __init__(
        self, created_at=None, parent_folder_id=None, child_nodes=None, name=None, id=None, child_lists=None, updated_contents_at=None, user_id=None, updated_at=None, local_vars_configuration=None
    ):  # noqa: E501
        """PublicListFolder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._parent_folder_id = None
        self._child_nodes = None
        self._name = None
        self._id = None
        self._child_lists = None
        self._updated_contents_at = None
        self._user_id = None
        self._updated_at = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        self.parent_folder_id = parent_folder_id
        self.child_nodes = child_nodes
        if name is not None:
            self.name = name
        self.id = id
        self.child_lists = child_lists
        if updated_contents_at is not None:
            self.updated_contents_at = updated_contents_at
        if user_id is not None:
            self.user_id = user_id
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this PublicListFolder.  # noqa: E501

        The time the folder was created at.  # noqa: E501

        :return: The created_at of this PublicListFolder.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PublicListFolder.

        The time the folder was created at.  # noqa: E501

        :param created_at: The created_at of this PublicListFolder.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this PublicListFolder.  # noqa: E501

        The Id of the folder this folder is in, the root folder is represented as 0.  # noqa: E501

        :return: The parent_folder_id of this PublicListFolder.  # noqa: E501
        :rtype: int
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this PublicListFolder.

        The Id of the folder this folder is in, the root folder is represented as 0.  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this PublicListFolder.  # noqa: E501
        :type parent_folder_id: int
        """
        if self.local_vars_configuration.client_side_validation and parent_folder_id is None:  # noqa: E501
            raise ValueError("Invalid value for `parent_folder_id`, must not be `None`")  # noqa: E501

        self._parent_folder_id = parent_folder_id

    @property
    def child_nodes(self):
        """Gets the child_nodes of this PublicListFolder.  # noqa: E501


        :return: The child_nodes of this PublicListFolder.  # noqa: E501
        :rtype: list[PublicListFolder]
        """
        return self._child_nodes

    @child_nodes.setter
    def child_nodes(self, child_nodes):
        """Sets the child_nodes of this PublicListFolder.


        :param child_nodes: The child_nodes of this PublicListFolder.  # noqa: E501
        :type child_nodes: list[PublicListFolder]
        """
        if self.local_vars_configuration.client_side_validation and child_nodes is None:  # noqa: E501
            raise ValueError("Invalid value for `child_nodes`, must not be `None`")  # noqa: E501

        self._child_nodes = child_nodes

    @property
    def name(self):
        """Gets the name of this PublicListFolder.  # noqa: E501

        The name of the folder.  # noqa: E501

        :return: The name of this PublicListFolder.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PublicListFolder.

        The name of the folder.  # noqa: E501

        :param name: The name of this PublicListFolder.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this PublicListFolder.  # noqa: E501

        The Id of the folder.  # noqa: E501

        :return: The id of this PublicListFolder.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicListFolder.

        The Id of the folder.  # noqa: E501

        :param id: The id of this PublicListFolder.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def child_lists(self):
        """Gets the child_lists of this PublicListFolder.  # noqa: E501

        An array of list Id's contained in this folder.  # noqa: E501

        :return: The child_lists of this PublicListFolder.  # noqa: E501
        :rtype: list[int]
        """
        return self._child_lists

    @child_lists.setter
    def child_lists(self, child_lists):
        """Sets the child_lists of this PublicListFolder.

        An array of list Id's contained in this folder.  # noqa: E501

        :param child_lists: The child_lists of this PublicListFolder.  # noqa: E501
        :type child_lists: list[int]
        """
        if self.local_vars_configuration.client_side_validation and child_lists is None:  # noqa: E501
            raise ValueError("Invalid value for `child_lists`, must not be `None`")  # noqa: E501

        self._child_lists = child_lists

    @property
    def updated_contents_at(self):
        """Gets the updated_contents_at of this PublicListFolder.  # noqa: E501

        The time that the contents of the folder was last updated at.  # noqa: E501

        :return: The updated_contents_at of this PublicListFolder.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_contents_at

    @updated_contents_at.setter
    def updated_contents_at(self, updated_contents_at):
        """Sets the updated_contents_at of this PublicListFolder.

        The time that the contents of the folder was last updated at.  # noqa: E501

        :param updated_contents_at: The updated_contents_at of this PublicListFolder.  # noqa: E501
        :type updated_contents_at: datetime
        """

        self._updated_contents_at = updated_contents_at

    @property
    def user_id(self):
        """Gets the user_id of this PublicListFolder.  # noqa: E501

        The user Id of the owner of the folder.  # noqa: E501

        :return: The user_id of this PublicListFolder.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PublicListFolder.

        The user Id of the owner of the folder.  # noqa: E501

        :param user_id: The user_id of this PublicListFolder.  # noqa: E501
        :type user_id: int
        """

        self._user_id = user_id

    @property
    def updated_at(self):
        """Gets the updated_at of this PublicListFolder.  # noqa: E501

        The time the folder was last updated at.  # noqa: E501

        :return: The updated_at of this PublicListFolder.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PublicListFolder.

        The time the folder was last updated at.  # noqa: E501

        :param updated_at: The updated_at of this PublicListFolder.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicListFolder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicListFolder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Communication Preferences Subscriptions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.communication_preferences.configuration import Configuration


class PublicUpdateSubscriptionStatusRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"email_address": "str", "legal_basis": "str", "subscription_id": "str", "legal_basis_explanation": "str"}

    attribute_map = {"email_address": "emailAddress", "legal_basis": "legalBasis", "subscription_id": "subscriptionId", "legal_basis_explanation": "legalBasisExplanation"}

    def __init__(self, email_address=None, legal_basis=None, subscription_id=None, legal_basis_explanation=None, local_vars_configuration=None):  # noqa: E501
        """PublicUpdateSubscriptionStatusRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._email_address = None
        self._legal_basis = None
        self._subscription_id = None
        self._legal_basis_explanation = None
        self.discriminator = None

        self.email_address = email_address
        if legal_basis is not None:
            self.legal_basis = legal_basis
        self.subscription_id = subscription_id
        if legal_basis_explanation is not None:
            self.legal_basis_explanation = legal_basis_explanation

    @property
    def email_address(self):
        """Gets the email_address of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501

        Contact's email address.  # noqa: E501

        :return: The email_address of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this PublicUpdateSubscriptionStatusRequest.

        Contact's email address.  # noqa: E501

        :param email_address: The email_address of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :type email_address: str
        """
        if self.local_vars_configuration.client_side_validation and email_address is None:  # noqa: E501
            raise ValueError("Invalid value for `email_address`, must not be `None`")  # noqa: E501

        self._email_address = email_address

    @property
    def legal_basis(self):
        """Gets the legal_basis of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501

        Legal basis for updating the contact's status (required for GDPR enabled portals).  # noqa: E501

        :return: The legal_basis of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._legal_basis

    @legal_basis.setter
    def legal_basis(self, legal_basis):
        """Sets the legal_basis of this PublicUpdateSubscriptionStatusRequest.

        Legal basis for updating the contact's status (required for GDPR enabled portals).  # noqa: E501

        :param legal_basis: The legal_basis of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :type legal_basis: str
        """
        allowed_values = [
            "LEGITIMATE_INTEREST_PQL",
            "LEGITIMATE_INTEREST_CLIENT",
            "PERFORMANCE_OF_CONTRACT",
            "CONSENT_WITH_NOTICE",
            "NON_GDPR",
            "PROCESS_AND_STORE",
            "LEGITIMATE_INTEREST_OTHER",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and legal_basis not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `legal_basis` ({0}), must be one of {1}".format(legal_basis, allowed_values))  # noqa: E501

        self._legal_basis = legal_basis

    @property
    def subscription_id(self):
        """Gets the subscription_id of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501

        ID of the subscription being updated for the contact.  # noqa: E501

        :return: The subscription_id of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this PublicUpdateSubscriptionStatusRequest.

        ID of the subscription being updated for the contact.  # noqa: E501

        :param subscription_id: The subscription_id of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :type subscription_id: str
        """
        if self.local_vars_configuration.client_side_validation and subscription_id is None:  # noqa: E501
            raise ValueError("Invalid value for `subscription_id`, must not be `None`")  # noqa: E501

        self._subscription_id = subscription_id

    @property
    def legal_basis_explanation(self):
        """Gets the legal_basis_explanation of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501

        A more detailed explanation to go with the legal basis (required for GDPR enabled portals).  # noqa: E501

        :return: The legal_basis_explanation of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._legal_basis_explanation

    @legal_basis_explanation.setter
    def legal_basis_explanation(self, legal_basis_explanation):
        """Sets the legal_basis_explanation of this PublicUpdateSubscriptionStatusRequest.

        A more detailed explanation to go with the legal basis (required for GDPR enabled portals).  # noqa: E501

        :param legal_basis_explanation: The legal_basis_explanation of this PublicUpdateSubscriptionStatusRequest.  # noqa: E501
        :type legal_basis_explanation: str
        """

        self._legal_basis_explanation = legal_basis_explanation

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicUpdateSubscriptionStatusRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicUpdateSubscriptionStatusRequest):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.extensions.cards.api.cards_api import CardsApi
from hubspot.crm.extensions.cards.api.sample_response_api import SampleResponseApi



# coding: utf-8

# flake8: noqa

"""
    Associations Schema

    Associations define the relationships between objects in HubSpot. These endpoints allow you to create, read, and remove associations.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.associations.schema.api.types_api import TypesApi

# import ApiClient
from hubspot.crm.associations.schema.api_client import ApiClient
from hubspot.crm.associations.schema.configuration import Configuration
from hubspot.crm.associations.schema.exceptions import OpenApiException
from hubspot.crm.associations.schema.exceptions import ApiTypeError
from hubspot.crm.associations.schema.exceptions import ApiValueError
from hubspot.crm.associations.schema.exceptions import ApiKeyError
from hubspot.crm.associations.schema.exceptions import ApiAttributeError
from hubspot.crm.associations.schema.exceptions import ApiException

# import models into sdk package
from hubspot.crm.associations.schema.models.collection_response_public_association_definition_no_paging import CollectionResponsePublicAssociationDefinitionNoPaging
from hubspot.crm.associations.schema.models.error import Error
from hubspot.crm.associations.schema.models.error_detail import ErrorDetail
from hubspot.crm.associations.schema.models.public_association_definition import PublicAssociationDefinition



# coding: utf-8

# flake8: noqa
"""
    CRM Associations Schema

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.associations.v4.schema.models.association_spec_with_label import AssociationSpecWithLabel
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_definition_configuration_create_request import BatchInputPublicAssociationDefinitionConfigurationCreateRequest
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_definition_configuration_update_request import BatchInputPublicAssociationDefinitionConfigurationUpdateRequest
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_spec import BatchInputPublicAssociationSpec
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_configuration_update_result import BatchResponsePublicAssociationDefinitionConfigurationUpdateResult
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_configuration_update_result_with_errors import (
    BatchResponsePublicAssociationDefinitionConfigurationUpdateResultWithErrors,
)
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_user_configuration import BatchResponsePublicAssociationDefinitionUserConfiguration
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_user_configuration_with_errors import BatchResponsePublicAssociationDefinitionUserConfigurationWithErrors
from hubspot.crm.associations.v4.schema.models.collection_response_association_spec_with_label_no_paging import CollectionResponseAssociationSpecWithLabelNoPaging
from hubspot.crm.associations.v4.schema.models.collection_response_public_association_definition_user_configuration_no_paging import (
    CollectionResponsePublicAssociationDefinitionUserConfigurationNoPaging,
)
from hubspot.crm.associations.v4.schema.models.error import Error
from hubspot.crm.associations.v4.schema.models.error_detail import ErrorDetail
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_create_request import PublicAssociationDefinitionConfigurationCreateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_update_request import PublicAssociationDefinitionConfigurationUpdateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_update_result import PublicAssociationDefinitionConfigurationUpdateResult
from hubspot.crm.associations.v4.schema.models.public_association_definition_create_request import PublicAssociationDefinitionCreateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_update_request import PublicAssociationDefinitionUpdateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_user_configuration import PublicAssociationDefinitionUserConfiguration
from hubspot.crm.associations.v4.schema.models.public_association_spec import PublicAssociationSpec
from hubspot.crm.associations.v4.schema.models.standard_error import StandardError



# coding: utf-8

"""
    Posts

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.blogs.blog_posts.configuration import Configuration


class Styles(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "background_color": "RGBAColor",
        "flexbox_positioning": "str",
        "background_image": "BackgroundImage",
        "force_full_width_section": "bool",
        "breakpoint_styles": "dict[str, BreakpointStyles]",
        "vertical_alignment": "str",
        "max_width_section_centering": "int",
        "background_gradient": "Gradient",
    }

    attribute_map = {
        "background_color": "backgroundColor",
        "flexbox_positioning": "flexboxPositioning",
        "background_image": "backgroundImage",
        "force_full_width_section": "forceFullWidthSection",
        "breakpoint_styles": "breakpointStyles",
        "vertical_alignment": "verticalAlignment",
        "max_width_section_centering": "maxWidthSectionCentering",
        "background_gradient": "backgroundGradient",
    }

    def __init__(
        self,
        background_color=None,
        flexbox_positioning=None,
        background_image=None,
        force_full_width_section=None,
        breakpoint_styles=None,
        vertical_alignment=None,
        max_width_section_centering=None,
        background_gradient=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Styles - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._background_color = None
        self._flexbox_positioning = None
        self._background_image = None
        self._force_full_width_section = None
        self._breakpoint_styles = None
        self._vertical_alignment = None
        self._max_width_section_centering = None
        self._background_gradient = None
        self.discriminator = None

        self.background_color = background_color
        self.flexbox_positioning = flexbox_positioning
        self.background_image = background_image
        self.force_full_width_section = force_full_width_section
        if breakpoint_styles is not None:
            self.breakpoint_styles = breakpoint_styles
        self.vertical_alignment = vertical_alignment
        self.max_width_section_centering = max_width_section_centering
        self.background_gradient = background_gradient

    @property
    def background_color(self):
        """Gets the background_color of this Styles.  # noqa: E501


        :return: The background_color of this Styles.  # noqa: E501
        :rtype: RGBAColor
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """Sets the background_color of this Styles.


        :param background_color: The background_color of this Styles.  # noqa: E501
        :type background_color: RGBAColor
        """
        if self.local_vars_configuration.client_side_validation and background_color is None:  # noqa: E501
            raise ValueError("Invalid value for `background_color`, must not be `None`")  # noqa: E501

        self._background_color = background_color

    @property
    def flexbox_positioning(self):
        """Gets the flexbox_positioning of this Styles.  # noqa: E501


        :return: The flexbox_positioning of this Styles.  # noqa: E501
        :rtype: str
        """
        return self._flexbox_positioning

    @flexbox_positioning.setter
    def flexbox_positioning(self, flexbox_positioning):
        """Sets the flexbox_positioning of this Styles.


        :param flexbox_positioning: The flexbox_positioning of this Styles.  # noqa: E501
        :type flexbox_positioning: str
        """
        if self.local_vars_configuration.client_side_validation and flexbox_positioning is None:  # noqa: E501
            raise ValueError("Invalid value for `flexbox_positioning`, must not be `None`")  # noqa: E501

        self._flexbox_positioning = flexbox_positioning

    @property
    def background_image(self):
        """Gets the background_image of this Styles.  # noqa: E501


        :return: The background_image of this Styles.  # noqa: E501
        :rtype: BackgroundImage
        """
        return self._background_image

    @background_image.setter
    def background_image(self, background_image):
        """Sets the background_image of this Styles.


        :param background_image: The background_image of this Styles.  # noqa: E501
        :type background_image: BackgroundImage
        """
        if self.local_vars_configuration.client_side_validation and background_image is None:  # noqa: E501
            raise ValueError("Invalid value for `background_image`, must not be `None`")  # noqa: E501

        self._background_image = background_image

    @property
    def force_full_width_section(self):
        """Gets the force_full_width_section of this Styles.  # noqa: E501


        :return: The force_full_width_section of this Styles.  # noqa: E501
        :rtype: bool
        """
        return self._force_full_width_section

    @force_full_width_section.setter
    def force_full_width_section(self, force_full_width_section):
        """Sets the force_full_width_section of this Styles.


        :param force_full_width_section: The force_full_width_section of this Styles.  # noqa: E501
        :type force_full_width_section: bool
        """
        if self.local_vars_configuration.client_side_validation and force_full_width_section is None:  # noqa: E501
            raise ValueError("Invalid value for `force_full_width_section`, must not be `None`")  # noqa: E501

        self._force_full_width_section = force_full_width_section

    @property
    def breakpoint_styles(self):
        """Gets the breakpoint_styles of this Styles.  # noqa: E501


        :return: The breakpoint_styles of this Styles.  # noqa: E501
        :rtype: dict[str, BreakpointStyles]
        """
        return self._breakpoint_styles

    @breakpoint_styles.setter
    def breakpoint_styles(self, breakpoint_styles):
        """Sets the breakpoint_styles of this Styles.


        :param breakpoint_styles: The breakpoint_styles of this Styles.  # noqa: E501
        :type breakpoint_styles: dict[str, BreakpointStyles]
        """

        self._breakpoint_styles = breakpoint_styles

    @property
    def vertical_alignment(self):
        """Gets the vertical_alignment of this Styles.  # noqa: E501


        :return: The vertical_alignment of this Styles.  # noqa: E501
        :rtype: str
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """Sets the vertical_alignment of this Styles.


        :param vertical_alignment: The vertical_alignment of this Styles.  # noqa: E501
        :type vertical_alignment: str
        """
        if self.local_vars_configuration.client_side_validation and vertical_alignment is None:  # noqa: E501
            raise ValueError("Invalid value for `vertical_alignment`, must not be `None`")  # noqa: E501

        self._vertical_alignment = vertical_alignment

    @property
    def max_width_section_centering(self):
        """Gets the max_width_section_centering of this Styles.  # noqa: E501


        :return: The max_width_section_centering of this Styles.  # noqa: E501
        :rtype: int
        """
        return self._max_width_section_centering

    @max_width_section_centering.setter
    def max_width_section_centering(self, max_width_section_centering):
        """Sets the max_width_section_centering of this Styles.


        :param max_width_section_centering: The max_width_section_centering of this Styles.  # noqa: E501
        :type max_width_section_centering: int
        """
        if self.local_vars_configuration.client_side_validation and max_width_section_centering is None:  # noqa: E501
            raise ValueError("Invalid value for `max_width_section_centering`, must not be `None`")  # noqa: E501

        self._max_width_section_centering = max_width_section_centering

    @property
    def background_gradient(self):
        """Gets the background_gradient of this Styles.  # noqa: E501


        :return: The background_gradient of this Styles.  # noqa: E501
        :rtype: Gradient
        """
        return self._background_gradient

    @background_gradient.setter
    def background_gradient(self, background_gradient):
        """Sets the background_gradient of this Styles.


        :param background_gradient: The background_gradient of this Styles.  # noqa: E501
        :type background_gradient: Gradient
        """
        if self.local_vars_configuration.client_side_validation and background_gradient is None:  # noqa: E501
            raise ValueError("Invalid value for `background_gradient`, must not be `None`")  # noqa: E501

        self._background_gradient = background_gradient

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Styles):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Styles):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Imports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.imports.configuration import Configuration


class PropertyValue(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "source_id": "str",
        "selected_by_user": "bool",
        "source_label": "str",
        "source": "str",
        "updated_by_user_id": "int",
        "persistence_timestamp": "int",
        "source_metadata": "str",
        "data_sensitivity": "str",
        "source_vid": "list[int]",
        "unit": "str",
        "request_id": "str",
        "is_encrypted": "bool",
        "name": "str",
        "use_timestamp_as_persistence_timestamp": "bool",
        "value": "str",
        "selected_by_user_timestamp": "int",
        "timestamp": "int",
        "is_large_value": "bool",
    }

    attribute_map = {
        "source_id": "sourceId",
        "selected_by_user": "selectedByUser",
        "source_label": "sourceLabel",
        "source": "source",
        "updated_by_user_id": "updatedByUserId",
        "persistence_timestamp": "persistenceTimestamp",
        "source_metadata": "sourceMetadata",
        "data_sensitivity": "dataSensitivity",
        "source_vid": "sourceVid",
        "unit": "unit",
        "request_id": "requestId",
        "is_encrypted": "isEncrypted",
        "name": "name",
        "use_timestamp_as_persistence_timestamp": "useTimestampAsPersistenceTimestamp",
        "value": "value",
        "selected_by_user_timestamp": "selectedByUserTimestamp",
        "timestamp": "timestamp",
        "is_large_value": "isLargeValue",
    }

    def __init__(
        self,
        source_id=None,
        selected_by_user=None,
        source_label=None,
        source=None,
        updated_by_user_id=None,
        persistence_timestamp=None,
        source_metadata=None,
        data_sensitivity=None,
        source_vid=None,
        unit=None,
        request_id=None,
        is_encrypted=None,
        name=None,
        use_timestamp_as_persistence_timestamp=None,
        value=None,
        selected_by_user_timestamp=None,
        timestamp=None,
        is_large_value=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PropertyValue - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._source_id = None
        self._selected_by_user = None
        self._source_label = None
        self._source = None
        self._updated_by_user_id = None
        self._persistence_timestamp = None
        self._source_metadata = None
        self._data_sensitivity = None
        self._source_vid = None
        self._unit = None
        self._request_id = None
        self._is_encrypted = None
        self._name = None
        self._use_timestamp_as_persistence_timestamp = None
        self._value = None
        self._selected_by_user_timestamp = None
        self._timestamp = None
        self._is_large_value = None
        self.discriminator = None

        self.source_id = source_id
        self.selected_by_user = selected_by_user
        self.source_label = source_label
        self.source = source
        self.updated_by_user_id = updated_by_user_id
        self.persistence_timestamp = persistence_timestamp
        self.source_metadata = source_metadata
        self.data_sensitivity = data_sensitivity
        self.source_vid = source_vid
        self.unit = unit
        self.request_id = request_id
        self.is_encrypted = is_encrypted
        self.name = name
        self.use_timestamp_as_persistence_timestamp = use_timestamp_as_persistence_timestamp
        self.value = value
        self.selected_by_user_timestamp = selected_by_user_timestamp
        self.timestamp = timestamp
        self.is_large_value = is_large_value

    @property
    def source_id(self):
        """Gets the source_id of this PropertyValue.  # noqa: E501


        :return: The source_id of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """Sets the source_id of this PropertyValue.


        :param source_id: The source_id of this PropertyValue.  # noqa: E501
        :type source_id: str
        """
        if self.local_vars_configuration.client_side_validation and source_id is None:  # noqa: E501
            raise ValueError("Invalid value for `source_id`, must not be `None`")  # noqa: E501

        self._source_id = source_id

    @property
    def selected_by_user(self):
        """Gets the selected_by_user of this PropertyValue.  # noqa: E501


        :return: The selected_by_user of this PropertyValue.  # noqa: E501
        :rtype: bool
        """
        return self._selected_by_user

    @selected_by_user.setter
    def selected_by_user(self, selected_by_user):
        """Sets the selected_by_user of this PropertyValue.


        :param selected_by_user: The selected_by_user of this PropertyValue.  # noqa: E501
        :type selected_by_user: bool
        """
        if self.local_vars_configuration.client_side_validation and selected_by_user is None:  # noqa: E501
            raise ValueError("Invalid value for `selected_by_user`, must not be `None`")  # noqa: E501

        self._selected_by_user = selected_by_user

    @property
    def source_label(self):
        """Gets the source_label of this PropertyValue.  # noqa: E501


        :return: The source_label of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._source_label

    @source_label.setter
    def source_label(self, source_label):
        """Sets the source_label of this PropertyValue.


        :param source_label: The source_label of this PropertyValue.  # noqa: E501
        :type source_label: str
        """
        if self.local_vars_configuration.client_side_validation and source_label is None:  # noqa: E501
            raise ValueError("Invalid value for `source_label`, must not be `None`")  # noqa: E501

        self._source_label = source_label

    @property
    def source(self):
        """Gets the source of this PropertyValue.  # noqa: E501


        :return: The source of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this PropertyValue.


        :param source: The source of this PropertyValue.  # noqa: E501
        :type source: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501
        allowed_values = [
            "UNKNOWN",
            "IMPORT",
            "API",
            "FORM",
            "ANALYTICS",
            "MIGRATION",
            "SALESFORCE",
            "INTEGRATION",
            "CONTACTS_WEB",
            "WAL_INCREMENTAL",
            "TASK",
            "EMAIL",
            "WORKFLOWS",
            "CALCULATED",
            "SOCIAL",
            "BATCH_UPDATE",
            "SIGNALS",
            "BIDEN",
            "DEFAULT",
            "COMPANIES",
            "DEALS",
            "ASSISTS",
            "PRESENTATIONS",
            "TALLY",
            "SIDEKICK",
            "CRM_UI",
            "MERGE_CONTACTS",
            "PORTAL_USER_ASSOCIATOR",
            "INTEGRATIONS_PLATFORM",
            "BCC_TO_CRM",
            "FORWARD_TO_CRM",
            "ENGAGEMENTS",
            "SALES",
            "HEISENBERG",
            "LEADIN",
            "GMAIL_INTEGRATION",
            "ACADEMY",
            "SALES_MESSAGES",
            "AVATARS_SERVICE",
            "MERGE_COMPANIES",
            "SEQUENCES",
            "COMPANY_FAMILIES",
            "MOBILE_IOS",
            "MOBILE_ANDROID",
            "CONTACTS",
            "ASSOCIATIONS",
            "EXTENSION",
            "SUCCESS",
            "BOT",
            "INTEGRATIONS_SYNC",
            "AUTOMATION_PLATFORM",
            "CONVERSATIONS",
            "EMAIL_INTEGRATION",
            "CONTENT_MEMBERSHIP",
            "QUOTES",
            "BET_ASSIGNMENT",
            "QUOTAS",
            "BET_CRM_CONNECTOR",
            "MEETINGS",
            "MERGE_OBJECTS",
            "RECYCLING_BIN",
            "ADS",
            "AI_GROUP",
            "COMMUNICATOR",
            "SETTINGS",
            "PROPERTY_SETTINGS",
            "PIPELINE_SETTINGS",
            "COMPANY_INSIGHTS",
            "BEHAVIORAL_EVENTS",
            "PAYMENTS",
            "GOALS",
            "PORTAL_OBJECT_SYNC",
            "APPROVALS",
            "FILE_MANAGER",
            "MARKETPLACE",
            "INTERNAL_PROCESSING",
            "FORECASTING",
            "SLACK_INTEGRATION",
            "CRM_UI_BULK_ACTION",
            "WORKFLOW_CONTACT_DELETE_ACTION",
            "ACCEPTANCE_TEST",
            "PLAYBOOKS",
            "CHATSPOT",
            "FLYWHEEL_PRODUCT_DATA_SYNC",
            "HELP_DESK",
            "BILLING",
            "DATA_ENRICHMENT",
            "AUTOMATION_JOURNEY",
            "MICROAPPS",
            "INTENT",
            "PROSPECTING_AGENT",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `source` ({0}), must be one of {1}".format(source, allowed_values))  # noqa: E501

        self._source = source

    @property
    def updated_by_user_id(self):
        """Gets the updated_by_user_id of this PropertyValue.  # noqa: E501


        :return: The updated_by_user_id of this PropertyValue.  # noqa: E501
        :rtype: int
        """
        return self._updated_by_user_id

    @updated_by_user_id.setter
    def updated_by_user_id(self, updated_by_user_id):
        """Sets the updated_by_user_id of this PropertyValue.


        :param updated_by_user_id: The updated_by_user_id of this PropertyValue.  # noqa: E501
        :type updated_by_user_id: int
        """
        if self.local_vars_configuration.client_side_validation and updated_by_user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_by_user_id`, must not be `None`")  # noqa: E501

        self._updated_by_user_id = updated_by_user_id

    @property
    def persistence_timestamp(self):
        """Gets the persistence_timestamp of this PropertyValue.  # noqa: E501


        :return: The persistence_timestamp of this PropertyValue.  # noqa: E501
        :rtype: int
        """
        return self._persistence_timestamp

    @persistence_timestamp.setter
    def persistence_timestamp(self, persistence_timestamp):
        """Sets the persistence_timestamp of this PropertyValue.


        :param persistence_timestamp: The persistence_timestamp of this PropertyValue.  # noqa: E501
        :type persistence_timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and persistence_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `persistence_timestamp`, must not be `None`")  # noqa: E501

        self._persistence_timestamp = persistence_timestamp

    @property
    def source_metadata(self):
        """Gets the source_metadata of this PropertyValue.  # noqa: E501


        :return: The source_metadata of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._source_metadata

    @source_metadata.setter
    def source_metadata(self, source_metadata):
        """Sets the source_metadata of this PropertyValue.


        :param source_metadata: The source_metadata of this PropertyValue.  # noqa: E501
        :type source_metadata: str
        """
        if self.local_vars_configuration.client_side_validation and source_metadata is None:  # noqa: E501
            raise ValueError("Invalid value for `source_metadata`, must not be `None`")  # noqa: E501

        self._source_metadata = source_metadata

    @property
    def data_sensitivity(self):
        """Gets the data_sensitivity of this PropertyValue.  # noqa: E501


        :return: The data_sensitivity of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._data_sensitivity

    @data_sensitivity.setter
    def data_sensitivity(self, data_sensitivity):
        """Sets the data_sensitivity of this PropertyValue.


        :param data_sensitivity: The data_sensitivity of this PropertyValue.  # noqa: E501
        :type data_sensitivity: str
        """
        if self.local_vars_configuration.client_side_validation and data_sensitivity is None:  # noqa: E501
            raise ValueError("Invalid value for `data_sensitivity`, must not be `None`")  # noqa: E501
        allowed_values = ["none", "standard", "high"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and data_sensitivity not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `data_sensitivity` ({0}), must be one of {1}".format(data_sensitivity, allowed_values))  # noqa: E501

        self._data_sensitivity = data_sensitivity

    @property
    def source_vid(self):
        """Gets the source_vid of this PropertyValue.  # noqa: E501


        :return: The source_vid of this PropertyValue.  # noqa: E501
        :rtype: list[int]
        """
        return self._source_vid

    @source_vid.setter
    def source_vid(self, source_vid):
        """Sets the source_vid of this PropertyValue.


        :param source_vid: The source_vid of this PropertyValue.  # noqa: E501
        :type source_vid: list[int]
        """
        if self.local_vars_configuration.client_side_validation and source_vid is None:  # noqa: E501
            raise ValueError("Invalid value for `source_vid`, must not be `None`")  # noqa: E501

        self._source_vid = source_vid

    @property
    def unit(self):
        """Gets the unit of this PropertyValue.  # noqa: E501


        :return: The unit of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this PropertyValue.


        :param unit: The unit of this PropertyValue.  # noqa: E501
        :type unit: str
        """
        if self.local_vars_configuration.client_side_validation and unit is None:  # noqa: E501
            raise ValueError("Invalid value for `unit`, must not be `None`")  # noqa: E501

        self._unit = unit

    @property
    def request_id(self):
        """Gets the request_id of this PropertyValue.  # noqa: E501


        :return: The request_id of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this PropertyValue.


        :param request_id: The request_id of this PropertyValue.  # noqa: E501
        :type request_id: str
        """
        if self.local_vars_configuration.client_side_validation and request_id is None:  # noqa: E501
            raise ValueError("Invalid value for `request_id`, must not be `None`")  # noqa: E501

        self._request_id = request_id

    @property
    def is_encrypted(self):
        """Gets the is_encrypted of this PropertyValue.  # noqa: E501


        :return: The is_encrypted of this PropertyValue.  # noqa: E501
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted):
        """Sets the is_encrypted of this PropertyValue.


        :param is_encrypted: The is_encrypted of this PropertyValue.  # noqa: E501
        :type is_encrypted: bool
        """
        if self.local_vars_configuration.client_side_validation and is_encrypted is None:  # noqa: E501
            raise ValueError("Invalid value for `is_encrypted`, must not be `None`")  # noqa: E501

        self._is_encrypted = is_encrypted

    @property
    def name(self):
        """Gets the name of this PropertyValue.  # noqa: E501


        :return: The name of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PropertyValue.


        :param name: The name of this PropertyValue.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def use_timestamp_as_persistence_timestamp(self):
        """Gets the use_timestamp_as_persistence_timestamp of this PropertyValue.  # noqa: E501


        :return: The use_timestamp_as_persistence_timestamp of this PropertyValue.  # noqa: E501
        :rtype: bool
        """
        return self._use_timestamp_as_persistence_timestamp

    @use_timestamp_as_persistence_timestamp.setter
    def use_timestamp_as_persistence_timestamp(self, use_timestamp_as_persistence_timestamp):
        """Sets the use_timestamp_as_persistence_timestamp of this PropertyValue.


        :param use_timestamp_as_persistence_timestamp: The use_timestamp_as_persistence_timestamp of this PropertyValue.  # noqa: E501
        :type use_timestamp_as_persistence_timestamp: bool
        """
        if self.local_vars_configuration.client_side_validation and use_timestamp_as_persistence_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `use_timestamp_as_persistence_timestamp`, must not be `None`")  # noqa: E501

        self._use_timestamp_as_persistence_timestamp = use_timestamp_as_persistence_timestamp

    @property
    def value(self):
        """Gets the value of this PropertyValue.  # noqa: E501


        :return: The value of this PropertyValue.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PropertyValue.


        :param value: The value of this PropertyValue.  # noqa: E501
        :type value: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def selected_by_user_timestamp(self):
        """Gets the selected_by_user_timestamp of this PropertyValue.  # noqa: E501


        :return: The selected_by_user_timestamp of this PropertyValue.  # noqa: E501
        :rtype: int
        """
        return self._selected_by_user_timestamp

    @selected_by_user_timestamp.setter
    def selected_by_user_timestamp(self, selected_by_user_timestamp):
        """Sets the selected_by_user_timestamp of this PropertyValue.


        :param selected_by_user_timestamp: The selected_by_user_timestamp of this PropertyValue.  # noqa: E501
        :type selected_by_user_timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and selected_by_user_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `selected_by_user_timestamp`, must not be `None`")  # noqa: E501

        self._selected_by_user_timestamp = selected_by_user_timestamp

    @property
    def timestamp(self):
        """Gets the timestamp of this PropertyValue.  # noqa: E501


        :return: The timestamp of this PropertyValue.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PropertyValue.


        :param timestamp: The timestamp of this PropertyValue.  # noqa: E501
        :type timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def is_large_value(self):
        """Gets the is_large_value of this PropertyValue.  # noqa: E501


        :return: The is_large_value of this PropertyValue.  # noqa: E501
        :rtype: bool
        """
        return self._is_large_value

    @is_large_value.setter
    def is_large_value(self, is_large_value):
        """Sets the is_large_value of this PropertyValue.


        :param is_large_value: The is_large_value of this PropertyValue.  # noqa: E501
        :type is_large_value: bool
        """
        if self.local_vars_configuration.client_side_validation and is_large_value is None:  # noqa: E501
            raise ValueError("Invalid value for `is_large_value`, must not be `None`")  # noqa: E501

        self._is_large_value = is_large_value

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PropertyValue):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PropertyValue):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.lists.api_client import ApiClient
from hubspot.crm.lists.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class FoldersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, list_folder_create_request, **kwargs):  # noqa: E501
        """Creates a folder  # noqa: E501

        Creates a folder with the given information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(list_folder_create_request, async_req=True)
        >>> result = thread.get()

        :param list_folder_create_request: (required)
        :type list_folder_create_request: ListFolderCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListFolderCreateResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(list_folder_create_request, **kwargs)  # noqa: E501

    def create_with_http_info(self, list_folder_create_request, **kwargs):  # noqa: E501
        """Creates a folder  # noqa: E501

        Creates a folder with the given information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(list_folder_create_request, async_req=True)
        >>> result = thread.get()

        :param list_folder_create_request: (required)
        :type list_folder_create_request: ListFolderCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListFolderCreateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_folder_create_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_folder_create_request' is set
        if self.api_client.client_side_validation and local_var_params.get("list_folder_create_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_folder_create_request` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "list_folder_create_request" in local_var_params:
            body_params = local_var_params["list_folder_create_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListFolderCreateResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/folders",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_all(self, **kwargs):  # noqa: E501
        """Retrieves a folder.  # noqa: E501

        Retrieves a folder and recursively includes all folders via the childNodes attribute.  The child lists field will be empty in all child nodes. Only the folder retrieved will include the child lists in that folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all(async_req=True)
        >>> result = thread.get()

        :param folder_id: The Id of the folder to retrieve.
        :type folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListFolderFetchResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.get_all_with_http_info(**kwargs)  # noqa: E501

    def get_all_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieves a folder.  # noqa: E501

        Retrieves a folder and recursively includes all folders via the childNodes attribute.  The child lists field will be empty in all child nodes. Only the folder retrieved will include the child lists in that folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_with_http_info(async_req=True)
        >>> result = thread.get()

        :param folder_id: The Id of the folder to retrieve.
        :type folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListFolderFetchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("folder_id") is not None:  # noqa: E501
            query_params.append(("folderId", local_var_params["folder_id"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListFolderFetchResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/folders",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def move(self, folder_id, new_parent_folder_id, **kwargs):  # noqa: E501
        """Moves a folder  # noqa: E501

        This moves the folder from its current location to a new location. It updates the parent of this folder to the new Id given.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.move(folder_id, new_parent_folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id:  (required)
        :type folder_id: str
        :param new_parent_folder_id:  (required)
        :type new_parent_folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListFolderFetchResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.move_with_http_info(folder_id, new_parent_folder_id, **kwargs)  # noqa: E501

    def move_with_http_info(self, folder_id, new_parent_folder_id, **kwargs):  # noqa: E501
        """Moves a folder  # noqa: E501

        This moves the folder from its current location to a new location. It updates the parent of this folder to the new Id given.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.move_with_http_info(folder_id, new_parent_folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id:  (required)
        :type folder_id: str
        :param new_parent_folder_id:  (required)
        :type new_parent_folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListFolderFetchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_id", "new_parent_folder_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method move" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `move`")  # noqa: E501
        # verify the required parameter 'new_parent_folder_id' is set
        if self.api_client.client_side_validation and local_var_params.get("new_parent_folder_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `new_parent_folder_id` when calling `move`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "folder_id" in local_var_params:
            path_params["folderId"] = local_var_params["folder_id"]  # noqa: E501
        if "new_parent_folder_id" in local_var_params:
            path_params["newParentFolderId"] = local_var_params["new_parent_folder_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListFolderFetchResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/folders/{folderId}/move/{newParentFolderId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def move_list(self, list_move_request, **kwargs):  # noqa: E501
        """Moves a list to a given folder  # noqa: E501

        Given a list and a folder, the list will be moved to that folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.move_list(list_move_request, async_req=True)
        >>> result = thread.get()

        :param list_move_request: (required)
        :type list_move_request: ListMoveRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.move_list_with_http_info(list_move_request, **kwargs)  # noqa: E501

    def move_list_with_http_info(self, list_move_request, **kwargs):  # noqa: E501
        """Moves a list to a given folder  # noqa: E501

        Given a list and a folder, the list will be moved to that folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.move_list_with_http_info(list_move_request, async_req=True)
        >>> result = thread.get()

        :param list_move_request: (required)
        :type list_move_request: ListMoveRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["list_move_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method move_list" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_move_request' is set
        if self.api_client.client_side_validation and local_var_params.get("list_move_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_move_request` when calling `move_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "list_move_request" in local_var_params:
            body_params = local_var_params["list_move_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/lists/folders/move-list",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def remove(self, folder_id, **kwargs):  # noqa: E501
        """Deletes a folder  # noqa: E501

        Deletes the folder with the given Id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id:  (required)
        :type folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.remove_with_http_info(folder_id, **kwargs)  # noqa: E501

    def remove_with_http_info(self, folder_id, **kwargs):  # noqa: E501
        """Deletes a folder  # noqa: E501

        Deletes the folder with the given Id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove_with_http_info(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id:  (required)
        :type folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["folder_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method remove" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `remove`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "folder_id" in local_var_params:
            path_params["folderId"] = local_var_params["folder_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/lists/folders/{folderId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def rename(self, folder_id, **kwargs):  # noqa: E501
        """Rename a folder  # noqa: E501

        Renames the given folderId with a new name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.rename(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id:  (required)
        :type folder_id: str
        :param new_folder_name:
        :type new_folder_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListFolderFetchResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.rename_with_http_info(folder_id, **kwargs)  # noqa: E501

    def rename_with_http_info(self, folder_id, **kwargs):  # noqa: E501
        """Rename a folder  # noqa: E501

        Renames the given folderId with a new name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.rename_with_http_info(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id:  (required)
        :type folder_id: str
        :param new_folder_name:
        :type new_folder_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListFolderFetchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_id", "new_folder_name"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method rename" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `rename`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "folder_id" in local_var_params:
            path_params["folderId"] = local_var_params["folder_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("new_folder_name") is not None:  # noqa: E501
            query_params.append(("newFolderName", local_var_params["new_folder_name"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListFolderFetchResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/folders/{folderId}/rename",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class Error(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"sub_category": "str", "context": "dict[str, list[str]]", "correlation_id": "str", "links": "dict[str, str]", "message": "str", "category": "str", "errors": "list[ErrorDetail]"}

    attribute_map = {"sub_category": "subCategory", "context": "context", "correlation_id": "correlationId", "links": "links", "message": "message", "category": "category", "errors": "errors"}

    def __init__(self, sub_category=None, context=None, correlation_id=None, links=None, message=None, category=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """Error - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._sub_category = None
        self._context = None
        self._correlation_id = None
        self._links = None
        self._message = None
        self._category = None
        self._errors = None
        self.discriminator = None

        if sub_category is not None:
            self.sub_category = sub_category
        if context is not None:
            self.context = context
        self.correlation_id = correlation_id
        if links is not None:
            self.links = links
        self.message = message
        self.category = category
        if errors is not None:
            self.errors = errors

    @property
    def sub_category(self):
        """Gets the sub_category of this Error.  # noqa: E501

        A specific category that contains more specific detail about the error  # noqa: E501

        :return: The sub_category of this Error.  # noqa: E501
        :rtype: str
        """
        return self._sub_category

    @sub_category.setter
    def sub_category(self, sub_category):
        """Sets the sub_category of this Error.

        A specific category that contains more specific detail about the error  # noqa: E501

        :param sub_category: The sub_category of this Error.  # noqa: E501
        :type sub_category: str
        """

        self._sub_category = sub_category

    @property
    def context(self):
        """Gets the context of this Error.  # noqa: E501

        Context about the error condition  # noqa: E501

        :return: The context of this Error.  # noqa: E501
        :rtype: dict[str, list[str]]
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this Error.

        Context about the error condition  # noqa: E501

        :param context: The context of this Error.  # noqa: E501
        :type context: dict[str, list[str]]
        """

        self._context = context

    @property
    def correlation_id(self):
        """Gets the correlation_id of this Error.  # noqa: E501

        A unique identifier for the request. Include this value with any error reports or support tickets  # noqa: E501

        :return: The correlation_id of this Error.  # noqa: E501
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """Sets the correlation_id of this Error.

        A unique identifier for the request. Include this value with any error reports or support tickets  # noqa: E501

        :param correlation_id: The correlation_id of this Error.  # noqa: E501
        :type correlation_id: str
        """
        if self.local_vars_configuration.client_side_validation and correlation_id is None:  # noqa: E501
            raise ValueError("Invalid value for `correlation_id`, must not be `None`")  # noqa: E501

        self._correlation_id = correlation_id

    @property
    def links(self):
        """Gets the links of this Error.  # noqa: E501

        A map of link names to associated URIs containing documentation about the error or recommended remediation steps  # noqa: E501

        :return: The links of this Error.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Error.

        A map of link names to associated URIs containing documentation about the error or recommended remediation steps  # noqa: E501

        :param links: The links of this Error.  # noqa: E501
        :type links: dict[str, str]
        """

        self._links = links

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501

        A human readable message describing the error along with remediation steps where appropriate  # noqa: E501

        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.

        A human readable message describing the error along with remediation steps where appropriate  # noqa: E501

        :param message: The message of this Error.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def category(self):
        """Gets the category of this Error.  # noqa: E501

        The error category  # noqa: E501

        :return: The category of this Error.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Error.

        The error category  # noqa: E501

        :param category: The category of this Error.  # noqa: E501
        :type category: str
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def errors(self):
        """Gets the errors of this Error.  # noqa: E501

        further information about the error  # noqa: E501

        :return: The errors of this Error.  # noqa: E501
        :rtype: list[ErrorDetail]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this Error.

        further information about the error  # noqa: E501

        :param errors: The errors of this Error.  # noqa: E501
        :type errors: list[ErrorDetail]
        """

        self._errors = errors

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Error):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Conversations Inbox & Messages

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from hubspot.conversations.conversations.api.actors_api import ActorsApi
from hubspot.conversations.conversations.api.channel_accounts_api import ChannelAccountsApi
from hubspot.conversations.conversations.api.channels_api import ChannelsApi
from hubspot.conversations.conversations.api.inboxes_api import InboxesApi
from hubspot.conversations.conversations.api.threads_api import ThreadsApi

# import ApiClient
from hubspot.conversations.conversations.api_response import ApiResponse
from hubspot.conversations.conversations.api_client import ApiClient
from hubspot.conversations.conversations.configuration import Configuration
from hubspot.conversations.conversations.exceptions import OpenApiException
from hubspot.conversations.conversations.exceptions import ApiTypeError
from hubspot.conversations.conversations.exceptions import ApiValueError
from hubspot.conversations.conversations.exceptions import ApiKeyError
from hubspot.conversations.conversations.exceptions import ApiAttributeError
from hubspot.conversations.conversations.exceptions import ApiException

# import models into sdk package
from hubspot.conversations.conversations.models.agent_actor import AgentActor
from hubspot.conversations.conversations.models.batch_input_string import BatchInputString
from hubspot.conversations.conversations.models.batch_response_public_actor import BatchResponsePublicActor
from hubspot.conversations.conversations.models.batch_response_public_actor_with_errors import BatchResponsePublicActorWithErrors
from hubspot.conversations.conversations.models.bot_actor import BotActor
from hubspot.conversations.conversations.models.collection_response_public_message_forward_paging import CollectionResponsePublicMessageForwardPaging
from hubspot.conversations.conversations.models.collection_response_public_thread_forward_paging import CollectionResponsePublicThreadForwardPaging
from hubspot.conversations.conversations.models.collection_response_with_total_public_channel_account_forward_paging import CollectionResponseWithTotalPublicChannelAccountForwardPaging
from hubspot.conversations.conversations.models.collection_response_with_total_public_channel_forward_paging import CollectionResponseWithTotalPublicChannelForwardPaging
from hubspot.conversations.conversations.models.collection_response_with_total_public_inbox_forward_paging import CollectionResponseWithTotalPublicInboxForwardPaging
from hubspot.conversations.conversations.models.contact_address import ContactAddress
from hubspot.conversations.conversations.models.contact_email import ContactEmail
from hubspot.conversations.conversations.models.contact_name import ContactName
from hubspot.conversations.conversations.models.contact_org import ContactOrg
from hubspot.conversations.conversations.models.contact_phone import ContactPhone
from hubspot.conversations.conversations.models.contact_profile import ContactProfile
from hubspot.conversations.conversations.models.contact_url import ContactUrl
from hubspot.conversations.conversations.models.email_actor import EmailActor
from hubspot.conversations.conversations.models.error import Error
from hubspot.conversations.conversations.models.error_detail import ErrorDetail
from hubspot.conversations.conversations.models.forward_paging import ForwardPaging
from hubspot.conversations.conversations.models.integrator_actor import IntegratorActor
from hubspot.conversations.conversations.models.next_page import NextPage
from hubspot.conversations.conversations.models.public_actor import PublicActor
from hubspot.conversations.conversations.models.public_actor_base import PublicActorBase
from hubspot.conversations.conversations.models.public_assignment_message import PublicAssignmentMessage
from hubspot.conversations.conversations.models.public_channel import PublicChannel
from hubspot.conversations.conversations.models.public_channel_account import PublicChannelAccount
from hubspot.conversations.conversations.models.public_client import PublicClient
from hubspot.conversations.conversations.models.public_comment import PublicComment
from hubspot.conversations.conversations.models.public_comment_all_of_attachments import PublicCommentAllOfAttachments
from hubspot.conversations.conversations.models.public_comment_egg import PublicCommentEgg
from hubspot.conversations.conversations.models.public_comment_egg_attachments_inner import PublicCommentEggAttachmentsInner
from hubspot.conversations.conversations.models.public_contact import PublicContact
from hubspot.conversations.conversations.models.public_conversations_message import PublicConversationsMessage
from hubspot.conversations.conversations.models.public_conversations_message_all_of_attachments import PublicConversationsMessageAllOfAttachments
from hubspot.conversations.conversations.models.public_conversations_message_egg import PublicConversationsMessageEgg
from hubspot.conversations.conversations.models.public_delivery_identifier import PublicDeliveryIdentifier
from hubspot.conversations.conversations.models.public_file import PublicFile
from hubspot.conversations.conversations.models.public_file_egg import PublicFileEgg
from hubspot.conversations.conversations.models.public_inbox import PublicInbox
from hubspot.conversations.conversations.models.public_location import PublicLocation
from hubspot.conversations.conversations.models.public_message import PublicMessage
from hubspot.conversations.conversations.models.public_message_base import PublicMessageBase
from hubspot.conversations.conversations.models.public_message_content import PublicMessageContent
from hubspot.conversations.conversations.models.public_message_egg import PublicMessageEgg
from hubspot.conversations.conversations.models.public_message_failure_details import PublicMessageFailureDetails
from hubspot.conversations.conversations.models.public_message_header import PublicMessageHeader
from hubspot.conversations.conversations.models.public_message_status import PublicMessageStatus
from hubspot.conversations.conversations.models.public_quick_replies import PublicQuickReplies
from hubspot.conversations.conversations.models.public_quick_replies_egg import PublicQuickRepliesEgg
from hubspot.conversations.conversations.models.public_recipient import PublicRecipient
from hubspot.conversations.conversations.models.public_recipient_egg import PublicRecipientEgg
from hubspot.conversations.conversations.models.public_sender import PublicSender
from hubspot.conversations.conversations.models.public_thread import PublicThread
from hubspot.conversations.conversations.models.public_thread_associations import PublicThreadAssociations
from hubspot.conversations.conversations.models.public_thread_inbox_change import PublicThreadInboxChange
from hubspot.conversations.conversations.models.public_thread_status_change import PublicThreadStatusChange
from hubspot.conversations.conversations.models.public_thread_update_request import PublicThreadUpdateRequest
from hubspot.conversations.conversations.models.public_unsupported_content import PublicUnsupportedContent
from hubspot.conversations.conversations.models.public_welcome_message import PublicWelcomeMessage
from hubspot.conversations.conversations.models.public_whats_app_template_metadata import PublicWhatsAppTemplateMetadata
from hubspot.conversations.conversations.models.quick_reply import QuickReply
from hubspot.conversations.conversations.models.standard_error import StandardError
from hubspot.conversations.conversations.models.system_actor import SystemActor
from hubspot.conversations.conversations.models.visitor_actor import VisitorActor



# coding: utf-8

# flake8: noqa
"""
    Pages

    Use these endpoints for interacting with Landing Pages and Site Pages  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.pages.models.ab_test_create_request_v_next import AbTestCreateRequestVNext
from hubspot.cms.pages.models.ab_test_end_request_v_next import AbTestEndRequestVNext
from hubspot.cms.pages.models.ab_test_rerun_request_v_next import AbTestRerunRequestVNext
from hubspot.cms.pages.models.angle import Angle
from hubspot.cms.pages.models.attach_to_lang_primary_request_v_next import AttachToLangPrimaryRequestVNext
from hubspot.cms.pages.models.background_image import BackgroundImage
from hubspot.cms.pages.models.batch_input_content_folder import BatchInputContentFolder
from hubspot.cms.pages.models.batch_input_json_node import BatchInputJsonNode
from hubspot.cms.pages.models.batch_input_page import BatchInputPage
from hubspot.cms.pages.models.batch_input_string import BatchInputString
from hubspot.cms.pages.models.batch_response_content_folder import BatchResponseContentFolder
from hubspot.cms.pages.models.batch_response_content_folder_with_errors import BatchResponseContentFolderWithErrors
from hubspot.cms.pages.models.batch_response_page import BatchResponsePage
from hubspot.cms.pages.models.batch_response_page_with_errors import BatchResponsePageWithErrors
from hubspot.cms.pages.models.collection_response_with_total_content_folder_forward_paging import CollectionResponseWithTotalContentFolderForwardPaging
from hubspot.cms.pages.models.collection_response_with_total_page_forward_paging import CollectionResponseWithTotalPageForwardPaging
from hubspot.cms.pages.models.collection_response_with_total_version_content_folder import CollectionResponseWithTotalVersionContentFolder
from hubspot.cms.pages.models.collection_response_with_total_version_page import CollectionResponseWithTotalVersionPage
from hubspot.cms.pages.models.color_stop import ColorStop
from hubspot.cms.pages.models.content_clone_request_v_next import ContentCloneRequestVNext
from hubspot.cms.pages.models.content_folder import ContentFolder
from hubspot.cms.pages.models.content_language_clone_request_v_next import ContentLanguageCloneRequestVNext
from hubspot.cms.pages.models.content_language_variation import ContentLanguageVariation
from hubspot.cms.pages.models.content_schedule_request_v_next import ContentScheduleRequestVNext
from hubspot.cms.pages.models.detach_from_lang_group_request_v_next import DetachFromLangGroupRequestVNext
from hubspot.cms.pages.models.error import Error
from hubspot.cms.pages.models.error_detail import ErrorDetail
from hubspot.cms.pages.models.forward_paging import ForwardPaging
from hubspot.cms.pages.models.gradient import Gradient
from hubspot.cms.pages.models.layout_section import LayoutSection
from hubspot.cms.pages.models.next_page import NextPage
from hubspot.cms.pages.models.page import Page
from hubspot.cms.pages.models.paging import Paging
from hubspot.cms.pages.models.previous_page import PreviousPage
from hubspot.cms.pages.models.rgba_color import RGBAColor
from hubspot.cms.pages.models.row_meta_data import RowMetaData
from hubspot.cms.pages.models.set_new_language_primary_request_v_next import SetNewLanguagePrimaryRequestVNext
from hubspot.cms.pages.models.side_or_corner import SideOrCorner
from hubspot.cms.pages.models.standard_error import StandardError
from hubspot.cms.pages.models.styles import Styles
from hubspot.cms.pages.models.update_languages_request_v_next import UpdateLanguagesRequestVNext
from hubspot.cms.pages.models.version_content_folder import VersionContentFolder
from hubspot.cms.pages.models.version_page import VersionPage
from hubspot.cms.pages.models.version_user import VersionUser



# coding: utf-8

# flake8: noqa

"""
    Visitor Identification

    The Visitor Identification API allows you to pass identification information to the HubSpot chat widget for otherwise unknown visitors that were verified by your own authentication system.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.conversations.visitor_identification.api.generate_api import GenerateApi

# import ApiClient
from hubspot.conversations.visitor_identification.api_client import ApiClient
from hubspot.conversations.visitor_identification.configuration import Configuration
from hubspot.conversations.visitor_identification.exceptions import OpenApiException
from hubspot.conversations.visitor_identification.exceptions import ApiTypeError
from hubspot.conversations.visitor_identification.exceptions import ApiValueError
from hubspot.conversations.visitor_identification.exceptions import ApiKeyError
from hubspot.conversations.visitor_identification.exceptions import ApiAttributeError
from hubspot.conversations.visitor_identification.exceptions import ApiException

# import models into sdk package
from hubspot.conversations.visitor_identification.models.error import Error
from hubspot.conversations.visitor_identification.models.error_detail import ErrorDetail
from hubspot.conversations.visitor_identification.models.identification_token_generation_request import IdentificationTokenGenerationRequest
from hubspot.conversations.visitor_identification.models.identification_token_response import IdentificationTokenResponse
